entdiff

package
v1.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 6, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the diff type in the database.
	Label = "diff"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldRequestID holds the string denoting the request_id field in the database.
	FieldRequestID = "request_id"
	// FieldFromResponseID holds the string denoting the from_response_id field in the database.
	FieldFromResponseID = "from_response_id"
	// FieldToResponseID holds the string denoting the to_response_id field in the database.
	FieldToResponseID = "to_response_id"
	// FieldContent holds the string denoting the content field in the database.
	FieldContent = "content"
	// FieldHasContent holds the string denoting the has_content field in the database.
	FieldHasContent = "has_content"
	// FieldConfig holds the string denoting the config field in the database.
	FieldConfig = "config"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// EdgeRequest holds the string denoting the request edge name in mutations.
	EdgeRequest = "request"
	// EdgeFromResponse holds the string denoting the from_response edge name in mutations.
	EdgeFromResponse = "from_response"
	// EdgeToResponse holds the string denoting the to_response edge name in mutations.
	EdgeToResponse = "to_response"
	// Table holds the table name of the diff in the database.
	Table = "diffs"
	// RequestTable is the table that holds the request relation/edge.
	RequestTable = "diffs"
	// RequestInverseTable is the table name for the Request entity.
	// It exists in this package in order to avoid circular dependency with the "request" package.
	RequestInverseTable = "requests"
	// RequestColumn is the table column denoting the request relation/edge.
	RequestColumn = "request_id"
	// FromResponseTable is the table that holds the from_response relation/edge.
	FromResponseTable = "diffs"
	// FromResponseInverseTable is the table name for the Response entity.
	// It exists in this package in order to avoid circular dependency with the "response" package.
	FromResponseInverseTable = "responses"
	// FromResponseColumn is the table column denoting the from_response relation/edge.
	FromResponseColumn = "from_response_id"
	// ToResponseTable is the table that holds the to_response relation/edge.
	ToResponseTable = "diffs"
	// ToResponseInverseTable is the table name for the Response entity.
	// It exists in this package in order to avoid circular dependency with the "response" package.
	ToResponseInverseTable = "responses"
	// ToResponseColumn is the table column denoting the to_response relation/edge.
	ToResponseColumn = "to_response_id"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for diff fields.

Functions

func And

func And(predicates ...predicate.Diff) predicate.Diff

And groups predicates with the AND operator between them.

func ConfigIsNil added in v1.4.0

func ConfigIsNil() predicate.Diff

ConfigIsNil applies the IsNil predicate on the "config" field.

func ConfigNotNil added in v1.4.0

func ConfigNotNil() predicate.Diff

ConfigNotNil applies the NotNil predicate on the "config" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Diff

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Diff

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Diff

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Diff

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Diff

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Diff

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Diff

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Diff

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Diff

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func FromResponseID

func FromResponseID(v uuid.UUID) predicate.Diff

FromResponseID applies equality check predicate on the "from_response_id" field. It's identical to FromResponseIDEQ.

func FromResponseIDEQ

func FromResponseIDEQ(v uuid.UUID) predicate.Diff

FromResponseIDEQ applies the EQ predicate on the "from_response_id" field.

func FromResponseIDIn

func FromResponseIDIn(vs ...uuid.UUID) predicate.Diff

FromResponseIDIn applies the In predicate on the "from_response_id" field.

func FromResponseIDNEQ

func FromResponseIDNEQ(v uuid.UUID) predicate.Diff

FromResponseIDNEQ applies the NEQ predicate on the "from_response_id" field.

func FromResponseIDNotIn

func FromResponseIDNotIn(vs ...uuid.UUID) predicate.Diff

FromResponseIDNotIn applies the NotIn predicate on the "from_response_id" field.

func HasContent added in v1.7.0

func HasContent(v bool) predicate.Diff

HasContent applies equality check predicate on the "has_content" field. It's identical to HasContentEQ.

func HasContentEQ added in v1.7.0

func HasContentEQ(v bool) predicate.Diff

HasContentEQ applies the EQ predicate on the "has_content" field.

func HasContentNEQ added in v1.7.0

func HasContentNEQ(v bool) predicate.Diff

HasContentNEQ applies the NEQ predicate on the "has_content" field.

func HasFromResponse

func HasFromResponse() predicate.Diff

HasFromResponse applies the HasEdge predicate on the "from_response" edge.

func HasFromResponseWith

func HasFromResponseWith(preds ...predicate.Response) predicate.Diff

HasFromResponseWith applies the HasEdge predicate on the "from_response" edge with a given conditions (other predicates).

func HasRequest

func HasRequest() predicate.Diff

HasRequest applies the HasEdge predicate on the "request" edge.

func HasRequestWith

func HasRequestWith(preds ...predicate.Request) predicate.Diff

HasRequestWith applies the HasEdge predicate on the "request" edge with a given conditions (other predicates).

func HasToResponse

func HasToResponse() predicate.Diff

HasToResponse applies the HasEdge predicate on the "to_response" edge.

func HasToResponseWith

func HasToResponseWith(preds ...predicate.Response) predicate.Diff

HasToResponseWith applies the HasEdge predicate on the "to_response" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Diff

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Diff

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Diff

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Diff

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Diff

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Diff

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Diff

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Diff

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Diff

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Diff) predicate.Diff

Or groups predicates with the OR operator between them.

func RequestID

func RequestID(v uuid.UUID) predicate.Diff

RequestID applies equality check predicate on the "request_id" field. It's identical to RequestIDEQ.

func RequestIDEQ

func RequestIDEQ(v uuid.UUID) predicate.Diff

RequestIDEQ applies the EQ predicate on the "request_id" field.

func RequestIDIn

func RequestIDIn(vs ...uuid.UUID) predicate.Diff

RequestIDIn applies the In predicate on the "request_id" field.

func RequestIDNEQ

func RequestIDNEQ(v uuid.UUID) predicate.Diff

RequestIDNEQ applies the NEQ predicate on the "request_id" field.

func RequestIDNotIn

func RequestIDNotIn(vs ...uuid.UUID) predicate.Diff

RequestIDNotIn applies the NotIn predicate on the "request_id" field.

func ToResponseID

func ToResponseID(v uuid.UUID) predicate.Diff

ToResponseID applies equality check predicate on the "to_response_id" field. It's identical to ToResponseIDEQ.

func ToResponseIDEQ

func ToResponseIDEQ(v uuid.UUID) predicate.Diff

ToResponseIDEQ applies the EQ predicate on the "to_response_id" field.

func ToResponseIDIn

func ToResponseIDIn(vs ...uuid.UUID) predicate.Diff

ToResponseIDIn applies the In predicate on the "to_response_id" field.

func ToResponseIDNEQ

func ToResponseIDNEQ(v uuid.UUID) predicate.Diff

ToResponseIDNEQ applies the NEQ predicate on the "to_response_id" field.

func ToResponseIDNotIn

func ToResponseIDNotIn(vs ...uuid.UUID) predicate.Diff

ToResponseIDNotIn applies the NotIn predicate on the "to_response_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Diff queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByFromResponseField

func ByFromResponseField(field string, opts ...sql.OrderTermOption) OrderOption

ByFromResponseField orders the results by from_response field.

func ByFromResponseID

func ByFromResponseID(opts ...sql.OrderTermOption) OrderOption

ByFromResponseID orders the results by the from_response_id field.

func ByHasContent added in v1.7.0

func ByHasContent(opts ...sql.OrderTermOption) OrderOption

ByHasContent orders the results by the has_content field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByRequestField

func ByRequestField(field string, opts ...sql.OrderTermOption) OrderOption

ByRequestField orders the results by request field.

func ByRequestID

func ByRequestID(opts ...sql.OrderTermOption) OrderOption

ByRequestID orders the results by the request_id field.

func ByToResponseField

func ByToResponseField(field string, opts ...sql.OrderTermOption) OrderOption

ByToResponseField orders the results by to_response field.

func ByToResponseID

func ByToResponseID(opts ...sql.OrderTermOption) OrderOption

ByToResponseID orders the results by the to_response_id field.

Jump to