Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Diff) predicate.Diff
- func ConfigIsNil() predicate.Diff
- func ConfigNotNil() predicate.Diff
- func CreatedAt(v time.Time) predicate.Diff
- func CreatedAtEQ(v time.Time) predicate.Diff
- func CreatedAtGT(v time.Time) predicate.Diff
- func CreatedAtGTE(v time.Time) predicate.Diff
- func CreatedAtIn(vs ...time.Time) predicate.Diff
- func CreatedAtLT(v time.Time) predicate.Diff
- func CreatedAtLTE(v time.Time) predicate.Diff
- func CreatedAtNEQ(v time.Time) predicate.Diff
- func CreatedAtNotIn(vs ...time.Time) predicate.Diff
- func FromResponseID(v uuid.UUID) predicate.Diff
- func FromResponseIDEQ(v uuid.UUID) predicate.Diff
- func FromResponseIDIn(vs ...uuid.UUID) predicate.Diff
- func FromResponseIDNEQ(v uuid.UUID) predicate.Diff
- func FromResponseIDNotIn(vs ...uuid.UUID) predicate.Diff
- func HasContent(v bool) predicate.Diff
- func HasContentEQ(v bool) predicate.Diff
- func HasContentNEQ(v bool) predicate.Diff
- func HasFromResponse() predicate.Diff
- func HasFromResponseWith(preds ...predicate.Response) predicate.Diff
- func HasRequest() predicate.Diff
- func HasRequestWith(preds ...predicate.Request) predicate.Diff
- func HasToResponse() predicate.Diff
- func HasToResponseWith(preds ...predicate.Response) predicate.Diff
- func ID(id uuid.UUID) predicate.Diff
- func IDEQ(id uuid.UUID) predicate.Diff
- func IDGT(id uuid.UUID) predicate.Diff
- func IDGTE(id uuid.UUID) predicate.Diff
- func IDIn(ids ...uuid.UUID) predicate.Diff
- func IDLT(id uuid.UUID) predicate.Diff
- func IDLTE(id uuid.UUID) predicate.Diff
- func IDNEQ(id uuid.UUID) predicate.Diff
- func IDNotIn(ids ...uuid.UUID) predicate.Diff
- func Not(p predicate.Diff) predicate.Diff
- func Or(predicates ...predicate.Diff) predicate.Diff
- func RequestID(v uuid.UUID) predicate.Diff
- func RequestIDEQ(v uuid.UUID) predicate.Diff
- func RequestIDIn(vs ...uuid.UUID) predicate.Diff
- func RequestIDNEQ(v uuid.UUID) predicate.Diff
- func RequestIDNotIn(vs ...uuid.UUID) predicate.Diff
- func ToResponseID(v uuid.UUID) predicate.Diff
- func ToResponseIDEQ(v uuid.UUID) predicate.Diff
- func ToResponseIDIn(vs ...uuid.UUID) predicate.Diff
- func ToResponseIDNEQ(v uuid.UUID) predicate.Diff
- func ToResponseIDNotIn(vs ...uuid.UUID) predicate.Diff
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByFromResponseField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByFromResponseID(opts ...sql.OrderTermOption) OrderOption
- func ByHasContent(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByRequestField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByRequestID(opts ...sql.OrderTermOption) OrderOption
- func ByToResponseField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByToResponseID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the diff type in the database. Label = "diff" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldRequestID holds the string denoting the request_id field in the database. FieldRequestID = "request_id" // FieldFromResponseID holds the string denoting the from_response_id field in the database. FieldFromResponseID = "from_response_id" // FieldToResponseID holds the string denoting the to_response_id field in the database. FieldToResponseID = "to_response_id" // FieldContent holds the string denoting the content field in the database. FieldContent = "content" // FieldHasContent holds the string denoting the has_content field in the database. FieldHasContent = "has_content" // FieldConfig holds the string denoting the config field in the database. FieldConfig = "config" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // EdgeRequest holds the string denoting the request edge name in mutations. EdgeRequest = "request" // EdgeFromResponse holds the string denoting the from_response edge name in mutations. EdgeFromResponse = "from_response" // EdgeToResponse holds the string denoting the to_response edge name in mutations. EdgeToResponse = "to_response" // Table holds the table name of the diff in the database. Table = "diffs" // RequestTable is the table that holds the request relation/edge. RequestTable = "diffs" // RequestInverseTable is the table name for the Request entity. // It exists in this package in order to avoid circular dependency with the "request" package. RequestInverseTable = "requests" // RequestColumn is the table column denoting the request relation/edge. RequestColumn = "request_id" // FromResponseTable is the table that holds the from_response relation/edge. FromResponseTable = "diffs" // FromResponseInverseTable is the table name for the Response entity. // It exists in this package in order to avoid circular dependency with the "response" package. FromResponseInverseTable = "responses" // FromResponseColumn is the table column denoting the from_response relation/edge. FromResponseColumn = "from_response_id" // ToResponseTable is the table that holds the to_response relation/edge. ToResponseTable = "diffs" // ToResponseInverseTable is the table name for the Response entity. // It exists in this package in order to avoid circular dependency with the "response" package. ToResponseInverseTable = "responses" // ToResponseColumn is the table column denoting the to_response relation/edge. ToResponseColumn = "to_response_id" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldRequestID, FieldFromResponseID, FieldToResponseID, FieldContent, FieldHasContent, FieldConfig, FieldCreatedAt, }
Columns holds all SQL columns for diff fields.
Functions ¶
func ConfigIsNil ¶ added in v1.4.0
ConfigIsNil applies the IsNil predicate on the "config" field.
func ConfigNotNil ¶ added in v1.4.0
ConfigNotNil applies the NotNil predicate on the "config" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func FromResponseID ¶
FromResponseID applies equality check predicate on the "from_response_id" field. It's identical to FromResponseIDEQ.
func FromResponseIDEQ ¶
FromResponseIDEQ applies the EQ predicate on the "from_response_id" field.
func FromResponseIDIn ¶
FromResponseIDIn applies the In predicate on the "from_response_id" field.
func FromResponseIDNEQ ¶
FromResponseIDNEQ applies the NEQ predicate on the "from_response_id" field.
func FromResponseIDNotIn ¶
FromResponseIDNotIn applies the NotIn predicate on the "from_response_id" field.
func HasContent ¶ added in v1.7.0
HasContent applies equality check predicate on the "has_content" field. It's identical to HasContentEQ.
func HasContentEQ ¶ added in v1.7.0
HasContentEQ applies the EQ predicate on the "has_content" field.
func HasContentNEQ ¶ added in v1.7.0
HasContentNEQ applies the NEQ predicate on the "has_content" field.
func HasFromResponse ¶
HasFromResponse applies the HasEdge predicate on the "from_response" edge.
func HasFromResponseWith ¶
HasFromResponseWith applies the HasEdge predicate on the "from_response" edge with a given conditions (other predicates).
func HasRequest ¶
HasRequest applies the HasEdge predicate on the "request" edge.
func HasRequestWith ¶
HasRequestWith applies the HasEdge predicate on the "request" edge with a given conditions (other predicates).
func HasToResponse ¶
HasToResponse applies the HasEdge predicate on the "to_response" edge.
func HasToResponseWith ¶
HasToResponseWith applies the HasEdge predicate on the "to_response" edge with a given conditions (other predicates).
func RequestID ¶
RequestID applies equality check predicate on the "request_id" field. It's identical to RequestIDEQ.
func RequestIDEQ ¶
RequestIDEQ applies the EQ predicate on the "request_id" field.
func RequestIDIn ¶
RequestIDIn applies the In predicate on the "request_id" field.
func RequestIDNEQ ¶
RequestIDNEQ applies the NEQ predicate on the "request_id" field.
func RequestIDNotIn ¶
RequestIDNotIn applies the NotIn predicate on the "request_id" field.
func ToResponseID ¶
ToResponseID applies equality check predicate on the "to_response_id" field. It's identical to ToResponseIDEQ.
func ToResponseIDEQ ¶
ToResponseIDEQ applies the EQ predicate on the "to_response_id" field.
func ToResponseIDIn ¶
ToResponseIDIn applies the In predicate on the "to_response_id" field.
func ToResponseIDNEQ ¶
ToResponseIDNEQ applies the NEQ predicate on the "to_response_id" field.
func ToResponseIDNotIn ¶
ToResponseIDNotIn applies the NotIn predicate on the "to_response_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Diff queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByFromResponseField ¶
func ByFromResponseField(field string, opts ...sql.OrderTermOption) OrderOption
ByFromResponseField orders the results by from_response field.
func ByFromResponseID ¶
func ByFromResponseID(opts ...sql.OrderTermOption) OrderOption
ByFromResponseID orders the results by the from_response_id field.
func ByHasContent ¶ added in v1.7.0
func ByHasContent(opts ...sql.OrderTermOption) OrderOption
ByHasContent orders the results by the has_content field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByRequestField ¶
func ByRequestField(field string, opts ...sql.OrderTermOption) OrderOption
ByRequestField orders the results by request field.
func ByRequestID ¶
func ByRequestID(opts ...sql.OrderTermOption) OrderOption
ByRequestID orders the results by the request_id field.
func ByToResponseField ¶
func ByToResponseField(field string, opts ...sql.OrderTermOption) OrderOption
ByToResponseField orders the results by to_response field.
func ByToResponseID ¶
func ByToResponseID(opts ...sql.OrderTermOption) OrderOption
ByToResponseID orders the results by the to_response_id field.